@@ -20,11 +20,7 @@ impl Beacon {
 	pub fn new(spec: Spec, framework: Framework, url: &Url) -> Result<Self, VerifierError> {
 		let mut info_url = url.clone();
 		info_url.set_path(Path::new(url.path()).join("info").to_str().unwrap_or(""));
-		let info: Json = ureq::get(&info_url.to_string())
-			.call()
-			.map_err(|e| VerifierError::RequestError(Box::new(e)))?
-			.into_json()
-			.unwrap();
+		let info: Json = reqwest::blocking::get(&info_url.to_string())?.json().unwrap();
 		log::trace!("{}", info);
 
 		Ok(Self {
@@ -101,11 +97,11 @@ impl Beacon {
 
 	fn valid_endpoint(&self, entity: &Entity, endpoint_url: &Url) -> EndpointReport {
 		// Query endpoint
-		let response = match ureq::get(endpoint_url.as_str()).call() {
+		let response = match reqwest::blocking::get(endpoint_url.as_str()) {
 			Ok(response) => response,
 			Err(e) => {
-				if let ureq::Error::Status(405, _) = e {
-					match ureq::post(endpoint_url.as_str()).call() {
+				if e.is_status() && e.status().unwrap().as_u16() == 405 {
+					match reqwest::blocking::Client::new().post(endpoint_url.as_str()).send() {
 						Ok(response) => response,
 						Err(e) => {
 							log::error!("{:?}", e);
@@ -121,7 +117,7 @@ impl Beacon {
 			},
 		};
 
-		let response_json = match response.into_json::<Json>() {
+		let response_json: Json = match response.json() {
 			Ok(response_json) => response_json,
 			Err(e) => {
 				log::error!("{:?}", e);
@@ -295,8 +291,11 @@ impl Beacon {
 						entity.name.clone(),
 						report_ids
 							.name(&format!(
-								"{} related with a single entry of {}",
-								related_enpoint.returned_entry_type,
+								"{} related with a {}",
+								self.spec
+									.entities_names
+									.get(&related_enpoint.returned_entry_type)
+									.unwrap_or(&String::from("Unknown entity")),
 								entity.name.clone()
 							))
 							.url(replaced_url_related.clone()),
